from setuptools import setup

setup(name='distributions1_probability',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['distributions1_probability'],
      author = "Eddy Caldas",
      author_email = "eddycaldas@live.com",
      zip_safe=False)
